@@ -146,7 +146,9 @@ and forces recomputation of load-more placeholders next time.
     (when (slack-room-member-p room)
       (oset room last-read ts)
       (slack-buffer-update-marker-overlay this)
-      (slack-conversations-mark room team ts after-success))))
+      (slack-conversations-mark room team ts after-success)
+      ;; update read counts after marking
+      (slack-counts-update slack-current-team))))
 
 (cl-defmethod slack-buffer-send-message ((this slack-message-buffer) message)
   (slack-message-send-internal message
@@ -846,14 +848,15 @@ Provide SUCCESS-CALLBACK to run some action after displaying."
 
 (defun slack-im-select ()
   (interactive)
-  (let* ((team (slack-team-select))
-         (candidates (cl-loop for team in (list team)
-                              for ims = (cl-remove-if #'(lambda (im)
-                                                          (not (oref im is-open)))
-                                                      (slack-team-ims team))
-                              nconc ims))
-         (room (slack-room-select candidates team)))
-    (slack-room-display room team)))
+  (if-let* ((team (slack-team-select))
+            (candidates (cl-loop for team in (list team)
+                                 for ims = (cl-remove-if #'(lambda (im)
+                                                             (not (slack-room-open-p im)))
+                                                         (slack-team-ims team))
+                                 nconc ims))
+            (room (slack-room-select candidates team)))
+      (slack-room-display room team)
+    (user-error "No open private chats available.")))
 
 (defun slack-group-select ()
   (interactive)
